@@ -10,7 +10,7 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!C")
+(in-package "SB-C")
 
 ;;; If non-NIL, emit assembly code. If NIL, emit VOP templates.
 (defvar *emit-assembly-code-not-vops-p* nil)
@@ -22,7 +22,9 @@
 ;;; COMPILE-FILE, but in fact it's arguably more like LOAD, even down
 ;;; to the return convention. It LOADs a file, then writes out any
 ;;; assembly code created by the process.
-(defun assemble-file (name &key (output-file (error "Missing keyword")))
+(defun assemble-file (name &key (output-file (error "Missing keyword"))
+                                print)
+  (declare (ignore print))
   (when sb-cold::*compile-for-effect-only*
     (return-from assemble-file t))
   (let* ((*emit-assembly-code-not-vops-p* t)
@@ -35,34 +37,41 @@
          (*asmstream* asmstream)
          (*adjustable-vectors* nil))
     (unwind-protect
-        (let ((*features* (cons :sb-assembling *features*)))
+        (let ((sb-xc:*features* (cons :sb-assembling sb-xc:*features*))
+              (*readtable* sb-cold:*xc-readtable*))
           (load (merge-pathnames name (make-pathname :type "lisp")))
-          ;; Leave room for the indirect call table. relocate_heap() in
-          ;; 'coreparse' finds the end with a 0 word so add 1 extra word.
-          #!+(or x86 x86-64)
-          (emit (asmstream-data-section asmstream)
-                `(.skip ,(* (align-up (1+ (length *entry-points*)) 2)
-                            sb!vm:n-word-bytes)))
-          (when (emit-inline-constants)
-            ;; Ensure alignment to double-Lispword in case a raw constant
-            ;; causes misalignment, as actually happens on ARM64.
-            ;; You might think one Lispword is aligned enough, but it isn't,
-            ;; because to created a tagged pointer to an asm routine,
-            ;; the base address must have all 0s in the tag bits.
-            ;; Note that for ordinary code components, alignment is ensured
-            ;; by SIMPLE-FUN-HEADER-WORD.
+          ;; Reserve space for the jump table. The first word of the table
+          ;; indicates the total length in words, counting the length word itself
+          ;; as a word, and the words comprising jump tables that were registered
+          ;; as unboxed constants. The logic in compiler/codegen splits unboxed
+          ;; constants into two groups: jump-tables and everything else, but that's
+          ;; because a code coverage map, if present, goes in between them.
+          ;; Assembly routines have no coverage map, so there is no need to split.
+          #+(or x86 x86-64)
+          (let ((n-extra-words
+                 (loop for ((category . data) . label)
+                       across (asmstream-constant-vector asmstream)
+                       when (eq category :jump-table) sum (length data))))
             (emit (asmstream-data-section asmstream)
-                  `(.align ,sb!vm:n-lowtag-bits)))
-          (let ((segment
-                 (assemble-sections
-                  (make-segment :inst-hook (default-segment-inst-hook)
-                                :run-scheduler nil)
-                  (asmstream-data-section asmstream)
-                  (asmstream-code-section asmstream)
-                  (asmstream-elsewhere-section asmstream))))
+                  `(.lispword ,(+ (length *entry-points*) n-extra-words 1))
+                  `(.skip ,(* (length *entry-points*) sb-vm:n-word-bytes))))
+          (emit-inline-constants)
+          ;; Ensure alignment to double-Lispword in case a raw constant
+          ;; causes misalignment, as actually happens on ARM64.
+          ;; You might think one Lispword is aligned enough, but it isn't,
+          ;; because to created a tagged pointer to an asm routine,
+          ;; the base address must have all 0s in the tag bits.
+          ;; Note that for code components that contain simple-funs,
+          ;; alignment is ensured by SIMPLE-FUN-HEADER-WORD.
+          (emit (asmstream-data-section asmstream)
+                `(.align ,sb-vm:n-lowtag-bits))
+          (let ((segment (assemble-sections
+                          asmstream nil
+                          (make-segment :inst-hook (default-segment-inst-hook)
+                                        :run-scheduler nil))))
             (dump-assembler-routines segment
                                      (segment-buffer segment)
-                                     (sb!assem::segment-fixup-notes segment)
+                                     (sb-assem::segment-fixup-notes segment)
                                      *entry-points*
                                      lap-fasl-output))
           (setq won t))
@@ -145,13 +154,13 @@
          ;; ARM. See the comment in arm/assem-rtns that says it expects THROW to
          ;; drop through into UNWIND. That wouldn't work if the code emitted
          ;; by GENERATE-ERROR-CODE were interposed between those.
-         #!-arm
+         #-arm
          (let ((asmstream *asmstream*))
-           (join-sections (asmstream-code-section asmstream)
-                          (asmstream-elsewhere-section asmstream)))
-         (emit-alignment sb!vm:n-lowtag-bits
+           (append-sections (list (asmstream-code-section asmstream)
+                                  (asmstream-elsewhere-section asmstream))))
+         (emit-alignment sb-vm:n-lowtag-bits
                          ;; EMIT-LONG-NOP does not exist for (not x86-64)
-                         #!+x86-64 :long-nop))
+                         #+x86-64 :long-nop))
        (when *compile-print*
          (format *error-output* "~S assembled~%" ',name)))))
 
@@ -170,7 +179,11 @@
          (return-style (or (cadr (assoc :return-style options)) :raw))
          (cost (or (cadr (assoc :cost options)) 247))
          (vop (make-symbol "VOP")))
-    (unless (member return-style '(:raw :full-call :none))
+    ;; :full-call-no-return entails the call site behavior for :full-call
+    ;; without automatic insertion of the return sequence. This avoids some confusion
+    ;; on the part of the human reading the code, especially if the asm routine
+    ;; tail calls something else.
+    (unless (member return-style '(:raw :full-call :none :full-call-no-return))
       (error "unknown return-style for ~S: ~S" name return-style))
     (multiple-value-bind (call-sequence call-temps)
         (generate-call-sequence name return-style vop options)
@@ -217,15 +230,15 @@
                       :key #'car)
          (:generator ,cost
            ,@(mapcar (lambda (arg)
-                       #!+(or hppa alpha) `(move ,(reg-spec-name arg)
+                       #+(or hppa alpha) `(move ,(reg-spec-name arg)
                                                  ,(reg-spec-temp arg))
-                       #!-(or hppa alpha) `(move ,(reg-spec-temp arg)
+                       #-(or hppa alpha) `(move ,(reg-spec-temp arg)
                                                  ,(reg-spec-name arg)))
                      args)
            ,@call-sequence
            ,@(mapcar (lambda (res)
-                       #!+(or hppa alpha) `(move ,(reg-spec-temp res)
+                       #+(or hppa alpha) `(move ,(reg-spec-temp res)
                                                  ,(reg-spec-name res))
-                       #!-(or hppa alpha) `(move ,(reg-spec-name res)
+                       #-(or hppa alpha) `(move ,(reg-spec-name res)
                                                  ,(reg-spec-temp res)))
                      results))))))
