@@ -10,10 +10,7 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!C")
-
-(declaim (type fixnum *compiler-sset-counter*))
-(defvar *compiler-sset-counter* 0)
+(in-package "SB-C")
 
 ;;; The front-end data structure (IR1) is composed of nodes,
 ;;; representing actual evaluations. Linear sequences of nodes in
@@ -63,11 +60,13 @@
   (use nil :type (or node null))
   ;; the basic block this continuation is in. This is null only in
   ;; :UNUSED continuations.
-  (block nil :type (or cblock null)))
+  (block nil :type (or cblock null))
+  ;; Entries created by the BLOCK special operator
+  (entries nil :type list))
 
 (defmethod print-object ((x ctran) stream)
   (print-unreadable-object (x stream :type t :identity t)
-    (when (boundp '*compiler-ir-obj-map*)
+    (when (boundp '*compilation*)
       (format stream "~D" (cont-num x)))))
 
 ;;; Linear VARiable. Multiple-value (possibly of unknown number)
@@ -87,9 +86,6 @@
   ;; the optimizer for this node type doesn't care, it can elect not
   ;; to clear this flag.
   (reoptimize t :type boolean)
-  ;; Cached type which is checked by DEST. If NIL, then this must be
-  ;; recomputed: see LVAR-EXTERNALLY-CHECKABLE-TYPE.
-  (%externally-checkable-type nil :type (or null ctype))
   ;; if the LVAR value is DYNAMIC-EXTENT, CLEANUP protecting it.
   (dynamic-extent nil :type (or null cleanup))
   ;; something or other that the back end annotates this lvar with
@@ -97,10 +93,10 @@
   (dependent-casts nil)
   (annotations nil)
   (dependent-annotations nil))
-(!set-load-form-method lvar (:xc :target) :ignore-it)
 
 ;;; These are used for annottating a LVAR with information that can't
-;;; be expressed using types.
+;;; be expressed using types or if the CAST semantics are undesirable
+;;; (type derivation, runtime errors).
 ;;; Right now it's basically used for tracking constants and checking
 ;;; them for things like proper sequence, or valid type specifier.
 (defstruct lvar-annotation
@@ -144,44 +140,44 @@
   (result-specs nil :type list)
   type)
 
+(defstruct (lvar-type-annotation
+            (:include lvar-annotation)
+            (:copier nil))
+  type
+  context)
+
 (defstruct (lvar-function-annotation
-             (:include lvar-annotation)
-             (:copier nil))
-  type)
+            (:include lvar-type-annotation)
+            (:copier nil)))
 
 (defmethod print-object ((x lvar) stream)
   (print-unreadable-object (x stream :type t :identity t)
-    (when (boundp '*compiler-ir-obj-map*)
+    (when (boundp '*compilation*)
       (format stream "~D" (cont-num x)))))
 
-#!-sb-fluid (declaim (inline lvar-has-single-use-p))
+#-sb-fluid (declaim (inline lvar-has-single-use-p))
 (defun lvar-has-single-use-p (lvar)
   (typep (lvar-uses lvar) '(not list)))
 
 ;;; Return the unique node, delivering a value to LVAR.
-#!-sb-fluid (declaim (inline lvar-use))
+#-sb-fluid (declaim (inline lvar-use))
 (defun lvar-use (lvar)
   (the (not list) (lvar-uses lvar)))
 
-#!-sb-fluid (declaim (inline lvar-derived-type))
+#-sb-fluid (declaim (inline lvar-derived-type))
 (defun lvar-derived-type (lvar)
   (declare (type lvar lvar))
   (or (lvar-%derived-type lvar)
       (setf (lvar-%derived-type lvar)
             (%lvar-derived-type lvar))))
 
-#!-sb-fluid(declaim (inline flush-lvar-externally-checkable-type))
-(defun flush-lvar-externally-checkable-type (lvar)
-  (declare (type lvar lvar))
-  (setf (lvar-%externally-checkable-type lvar) nil))
-
 (def!struct (node (:constructor nil)
                   (:include sset-element
-                            (number (unless (eql *compiler-sset-counter* 0)
-                                      (incf *compiler-sset-counter*))))
+                            (number (when (boundp '*compilation*)
+                                      (incf (sset-counter *compilation*)))))
                   (:copier nil))
   ;; unique ID for debugging
-  #!+sb-show (id (new-object-id) :read-only t)
+  #+sb-show (id (new-object-id) :read-only t)
   ;; True if this node needs to be optimized. This is set to true
   ;; whenever something changes about the value of an lvar whose DEST
   ;; is this node.
@@ -229,7 +225,7 @@
   ;; can null out this slot.
   (tail-p nil :type boolean))
 
-#!-sb-fluid (declaim (inline node-block))
+#-sb-fluid (declaim (inline node-block))
 (defun node-block (node)
   (ctran-block (node-prev node)))
 
@@ -252,7 +248,7 @@
   ;; the value is unused.
   (lvar nil :type (or lvar null)))
 
-#!-sb-fluid (declaim (inline node-dest))
+#-sb-fluid (declaim (inline node-dest))
 (defun node-dest (node)
   (awhen (node-lvar node) (lvar-dest it)))
 
@@ -397,7 +393,7 @@
   ;; no cached value has been stored yet.
   (physenv-cache :none :type (or null physenv (member :none))))
 (defmethod print-object ((cblock cblock) stream)
-  (if (boundp '*compiler-ir-obj-map*)
+  (if (boundp '*compilation*)
       (print-unreadable-object (cblock stream :type t :identity t)
         (format stream "~W :START c~W"
             (block-number cblock)
@@ -435,8 +431,7 @@
   ;; the INFO slot as :type (or (satisfies ir2-component-p) ...)
   ;; During make-host-2, the solution to this is the same hack
   ;; as for everything else: use DEF!STRUCT for IR2-COMPONENT.
-  #!+(and (host-feature sb-xc-host) (host-feature sbcl))
-  (declare (host-sb-ext:muffle-conditions style-warning))
+  #+host-quirks-sbcl (declare (host-sb-ext:muffle-conditions style-warning))
 (def!struct (component (:copier nil)
                        (:constructor
                         make-component
@@ -445,7 +440,7 @@
                          (last-block tail)
                          (outer-loop (make-loop :kind :outer :head head)))))
   ;; unique ID for debugging
-  #!+sb-show (id (new-object-id) :read-only t)
+  #+sb-show (id (new-object-id) :read-only t)
   ;; space where this component will be allocated in
   ;; :auto won't make any codegen optimizations pertinent to immobile space,
   ;; but will place the code there given sufficient available space.
@@ -554,14 +549,13 @@
   (sset-number 0 :type fixnum)))
 (defprinter (component :identity t)
   name
-  #!+sb-show id
+  #+sb-show id
   (reanalyze :test reanalyze))
 
 (declaim (inline reoptimize-component))
 (defun reoptimize-component (component kind)
   (declare (type component component)
-           (type (member nil :maybe t) kind))
-  (aver kind)
+           (type (member :maybe t) kind))
   (unless (eq (component-reoptimize component) t)
     (setf (component-reoptimize component) kind)))
 
@@ -593,7 +587,7 @@
   (kind (missing-arg)
         :type (member :special-bind :catch :unwind-protect
                       :block :tagbody :dynamic-extent
-                      #!-c-stack-is-control-stack :restore-nsp))
+                      #-c-stack-is-control-stack :restore-nsp))
   ;; the node that messes things up. This is the last node in the
   ;; non-messed-up environment. Null only temporarily. This could be
   ;; deleted due to unreachability.
@@ -723,7 +717,6 @@
   (safe-p nil :type boolean)
   ;; some kind of info used by the back end
   info)
-(!set-load-form-method nlx-info (:xc :target) :ignore-it)
 (defprinter (nlx-info :identity t)
   block
   target
@@ -736,12 +729,12 @@
 ;;; allows us to easily substitute one for the other without actually
 ;;; hacking the flow graph.
 (def!struct (leaf (:include sset-element
-                            (number (unless (eql *compiler-sset-counter* 0)
-                                      (incf *compiler-sset-counter*))))
+                            (number (when (boundp '*compilation*)
+                                      (incf (sset-counter *compilation*)))))
                   (:copier nil)
                   (:constructor nil))
   ;; unique ID for debugging
-  #!+sb-show (id (new-object-id) :read-only t)
+  #+sb-show (id (new-object-id) :read-only t)
   ;; (For public access to this slot, use LEAF-SOURCE-NAME.)
   ;;
   ;; the name of LEAF as it appears in the source, e.g. 'FOO or '(SETF
@@ -786,14 +779,13 @@
   ;; be true when REFS and SETS are null, since code can be deleted.
   (ever-used nil :type boolean)
   ;; is it declared dynamic-extent, or truly-dynamic-extent?
-  (extent nil :type (member nil :maybe-dynamic :always-dynamic :indefinite))
+  (extent nil :type (member nil truly-dynamic-extent dynamic-extent indefinite-extent))
   ;; some kind of info used by the back end
   (info nil))
-(!set-load-form-method leaf (:xc :target) :ignore-it)
 
 (defun leaf-dynamic-extent (leaf)
   (let ((extent (leaf-extent leaf)))
-    (unless (member extent '(nil :indefinite))
+    (unless (member extent '(nil indefinite-extent))
       extent)))
 
 ;;; LEAF name operations
@@ -830,7 +822,7 @@
              :pretty-ir-printer
              (pretty-print-global-var structure stream))
   %source-name
-  #!+sb-show id
+  #+sb-show id
   (type :test (not (eq type *universal-type*)))
   (defined-type :test (not (eq defined-type *universal-type*)))
   (where-from :test (not (eq where-from :assumed)))
@@ -839,9 +831,9 @@
 (defun fun-locally-defined-p (name env)
   (typecase env
     (null nil)
-    #!+(and sb-fasteval (host-feature sb-xc))
-    (sb!interpreter:basic-env
-     (values (sb!interpreter:find-lexical-fun env name)))
+    #+(and sb-fasteval (not sb-xc-host))
+    (sb-interpreter:basic-env
+     (values (sb-interpreter:find-lexical-fun env name)))
     (t
      (let ((fun (cdr (assoc name (lexenv-funs env) :test #'equal))))
        (and fun (not (global-var-p fun)))))))
@@ -867,7 +859,7 @@
 (defprinter (defined-fun :identity t
              :pretty-ir-printer (pretty-print-global-var structure stream))
   %source-name
-  #!+sb-show id
+  #+sb-show id
   inlinep
   (functionals :test functionals))
 
@@ -1041,7 +1033,7 @@
              :pretty-ir-printer (pretty-print-functional structure stream))
   %source-name
   %debug-name
-  #!+sb-show id)
+  #+sb-show id)
 
 (defun leaf-debug-name (leaf)
   (if (functional-p leaf)
@@ -1098,7 +1090,7 @@
                      (:constructor make-lambda)
                      (:copier nil))
   ;; list of LAMBDA-VAR descriptors for arguments
-  (vars nil :type list :read-only t)
+  (vars nil :type list)
   ;; If this function was ever a :OPTIONAL function (an entry-point
   ;; for an OPTIONAL-DISPATCH), then this is that OPTIONAL-DISPATCH.
   ;; The optional dispatch will be :DELETED if this function is no
@@ -1162,7 +1154,7 @@
              :pretty-ir-printer (pretty-print-functional structure stream))
   %source-name
   %debug-name
-  #!+sb-show id
+  #+sb-show id
   kind
   (type :test (not (eq type *universal-type*)))
   (where-from :test (not (eq where-from :assumed)))
@@ -1244,7 +1236,7 @@
              :pretty-ir-printer (pretty-print-functional structure stream))
   %source-name
   %debug-name
-  #!+sb-show id
+  #+sb-show id
   (type :test (not (eq type *universal-type*)))
   (where-from :test (not (eq where-from :assumed)))
   arglist
@@ -1347,12 +1339,15 @@
   (eql-var-constraints     nil :type (or null (array t 1)))
   (inheritable-constraints nil :type (or null (array t 1)))
   (private-constraints     nil :type (or null (array t 1)))
+  (equality-constraints    nil :type (or null (array t 1)))
+
   ;; The FOP handle of the lexical variable represented by LAMBDA-VAR
   ;; in the fopcompiler.
-  (fop-value nil))
+  (fop-value nil)
+  source-form)
 (defprinter (lambda-var :identity t)
   %source-name
-  #!+sb-show id
+  #+sb-show id
   (type :test (not (eq type *universal-type*)))
   (where-from :test (not (eq where-from :assumed)))
   (flags :test (not (zerop flags))
@@ -1391,7 +1386,7 @@
   ;; Constraints that cannot be expressed as NODE-DERIVED-TYPE
   constraints)
 (defprinter (ref :identity t)
-  #!+sb-show id
+  #+sb-show id
   (%source-name :test (neq %source-name '.anonymous.))
   leaf)
 
@@ -1469,7 +1464,7 @@
                          (:constructor make-combination (fun))
                          (:copier nil)))
 (defprinter (combination :identity t)
-  #!+sb-show id
+  #+sb-show id
   (fun :prin1 (lvar-uses fun))
   (args :prin1 (mapcar (lambda (x)
                          (if x
@@ -1593,7 +1588,7 @@
   ;; The cleanup for this entry. NULL only temporarily.
   (cleanup nil :type (or cleanup null)))
 (defprinter (entry :identity t)
-  #!+sb-show id)
+  #+sb-show id)
 
 ;;; The EXIT node marks the place at which exit code would be emitted,
 ;;; if necessary. This is interposed between the uses of the exit
@@ -1614,7 +1609,7 @@
   (value nil :type (or lvar null))
   (nlx-info nil :type (or nlx-info null)))
 (defprinter (exit :identity t)
-  #!+sb-show id
+  #+sb-show id
   (entry :test entry)
   (value :test value))
 
@@ -1634,8 +1629,9 @@
 (defun %coerce-to-policy (thing)
   (typecase thing
     (policy thing)
-    #!+(and sb-fasteval (host-feature sb-xc))
-    (sb!interpreter:basic-env (sb!interpreter:env-policy thing))
+    #+(and sb-fasteval (not sb-xc-host))
+    (sb-interpreter:basic-env (sb-interpreter:env-policy thing))
+    ;; Why not *policy*?
     (null **baseline-policy**)
     (t (lexenv-policy (etypecase thing
                         (lexenv thing)
@@ -1647,7 +1643,7 @@
 ;; FIXME: the frozen-ness can't actually help optimize anything
 ;; until this file is compiled by the cross-compiler.
 ;; Anything compiled prior to then uses the non-frozen classoid as existed
-;; at load-time of the cross-compiler. SB!XC:PROCLAIM would likely work here.
-#!-sb-fluid
+;; at load-time of the cross-compiler. SB-XC:PROCLAIM would likely work here.
+#-sb-fluid
 (declaim (freeze-type node lexenv ctran lvar cblock component cleanup
                       physenv tail-set nlx-info))
