@@ -305,24 +305,30 @@
          (inst mov rsp-tn rbx-tn)))
       (t
        (collect ((defaults))
-         (let ((default-stack-slots (gen-label)))
+         (let ((default-stack-slots (gen-label))
+               (used-registers
+                 (loop for i from 1 below register-arg-count
+                       for tn = (tn-ref-tn (setf values (tn-ref-across values)))
+                       unless (eq (tn-kind tn) :unused)
+                       collect tn
+                       finally (setf values (tn-ref-across values))))
+               (used-stack-slots-p
+                 (loop for ref = values then (tn-ref-across ref)
+                       while ref
+                       thereis (neq (tn-kind (tn-ref-tn ref)) :unused))))
           (assemble ()
             (note-this-location vop :unknown-return)
-            ;; Branch off to the MV case.
-            (inst jmp :c regs-defaulted)
-            ;; Do the single value case.
-            ;; Default the register args
-            (do ((i 1 (1+ i))
-                 (val (tn-ref-across values) (tn-ref-across val)))
-                ((= i register-arg-count) (setf values val))
-              (unless (eq (tn-kind (tn-ref-tn val)) :unused)
-                (inst mov (tn-ref-tn val) nil-value)))
-            (move rbx-tn rsp-tn)
-            (if (loop for ref = values then (tn-ref-across ref)
-                      while ref
-                      thereis (neq (tn-kind (tn-ref-tn ref)) :unused))
-                (inst jmp default-stack-slots)
-                (inst jmp defaulting-done))
+            ;; If it returned exactly one value the registers and the
+            ;; stack slots need to be filled with NIL.
+            (cond (used-stack-slots-p
+                   (inst jmp :nc default-stack-slots))
+                  (t
+                   (inst jmp :c regs-defaulted)
+                   (loop for null = nil-value then (car used-registers)
+                         for reg in used-registers
+                         do (inst mov :dword reg null))
+                   (move rbx-tn rsp-tn)
+                   (inst jmp defaulting-done)))
             REGS-DEFAULTED
             (do ((i register-arg-count (1+ i))
                  (val values (tn-ref-across val)))
@@ -347,6 +353,10 @@
               (when defaults
                 (assemble (:elsewhere)
                   (emit-label default-stack-slots)
+                  (loop for null = nil-value then (car used-registers)
+                        for reg in used-registers
+                        do (inst mov :dword reg null))
+                  (move rbx-tn rsp-tn)
                   (dolist (default defaults)
                     (emit-label (car default))
                     (inst mov (cdr default) nil-value))
@@ -398,13 +408,11 @@
       #+#.(cl:if (cl:= sb-vm:word-shift sb-vm:n-fixnum-tag-bits) '(and) '(or))
       (inst sub rsp-tn nargs)
       #-#.(cl:if (cl:= sb-vm:word-shift sb-vm:n-fixnum-tag-bits) '(and) '(or))
-      (progn
-        ;; FIXME: This can't be efficient, but LEA (my first choice)
-        ;; doesn't do subtraction.
-        (inst shl nargs (- word-shift n-fixnum-tag-bits))
-        (inst sub rsp-tn nargs)
+      (let ((sub nargs))
         (unless unused-count-p
-          (inst shr nargs (- word-shift n-fixnum-tag-bits))))
+          (inst mov :dword (setf sub rax-tn) nargs))
+        (inst shl :dword sub (- word-shift n-fixnum-tag-bits))
+        (inst sub rsp-tn sub))
       (emit-label stack-values))
     ;; dtc: this writes the registers onto the stack even if they are
     ;; not needed, only the number specified in rcx are used and have
@@ -1083,7 +1091,8 @@
   (:generator 20
     ;; Avoid the copy if there are no more args.
     (cond ((zerop fixed)
-           (inst jrcxz JUST-ALLOC-FRAME))
+           (inst test rcx-tn rcx-tn)
+           (inst jmp :z JUST-ALLOC-FRAME))
           ((and (eql min-verified fixed)
                 (> fixed 1))
            ;; verify-arg-count will do a CMP
@@ -1275,7 +1284,8 @@
       (move rcx count)
       ;; Check to see whether there are no args, and just return NIL if so.
       (inst mov result nil-value)
-      (inst jrcxz done)
+      (inst test rcx rcx)
+      (inst jmp :z done)
       (inst lea dst (ea nil rcx (ash 2 (- word-shift n-fixnum-tag-bits))))
       (unless stack-allocate-p
         (instrument-alloc dst node))
